Crate fetcher_core
source ·Expand description
fetcher-core
The building blocks for fetcher. fetcher-core has everything related to running a job, a task, or some part thereof. See each individual module for documention specifying their usage or fetcher for more info.
Modules
- This module contains all external manual authentication implementations. For now it’s just
Google OAuth2 - This module contains all errors that
fetchercan emit - This module contains the
ExternalSavetrait that implementors can use to add a way to save read filter data and entry to message map externally, - This module contains the
Jobstruct and the entryway to the library - This module contains the
ReadFilterthat is used for keeping track of what Entry has been or not been read, including all of its stragedies - Miscellaneous utility extention traits for external types