Enum fetcher_core::action::Action
source · pub enum Action {
Filter(Box<dyn Filter>),
Transform(Box<dyn Transform>),
}Expand description
An action that modifies a list of entries in some way
Variants
Filter(Box<dyn Filter>)
Filter out entries
Transform(Box<dyn Transform>)
Transform some entries into one or more new entries
Implementations