Module fetcher_core::action::transform
source · Expand description
This module contains TransformEntry and TransformField traits as well as all types that implement it
Re-exports
pub use self::entry::feed::Feed;pub use self::entry::html::Html;pub use self::entry::http::Http;pub use self::entry::json::Json;pub use self::entry::print::DebugPrint;pub use self::entry::use_as::Use;pub use self::field::caps::Caps;pub use self::field::set::Set;pub use self::field::shorten::Shorten;pub use self::field::trim::Trim;
Modules
- This module contains the
TransformEntrytrait as well as every type that implement it - This module contains all errors that can happen in the (
parent)supermodule - This module contains the trait
TransformFieldas well as all types that implement it AndFieldenum that can be used to refer to aMessage’s field - This module contains everything needed to contruct a new
Entry(viaTransformedEntry) andMessage(viaTransformedMessage) after parsing, optionally using previousEntry'sdata if requested