pub struct Query {
pub keys: Keys,
pub optional: bool,
}Expand description
A query to get the value of a JSON field
Fields
keys: Keysa chain of JSON keys that are needed to be traversed to get to this key
optional: boolwhether this query is fine to be ignored if not found