pub trait TransformEntry: Debug {
    type Err: Into<TransformErrorKind>;

    // Required method
    fn transform_entry<'life0, 'async_trait>(
        &'life0 self,
        entry: Entry
    ) -> Pin<Box<dyn Future<Output = Result<Vec<TransformedEntry>, Self::Err>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Transform an entry into one or more entries. This is the type transforms should implement as it includes easier error management

Required Associated Types

source

type Err: Into<TransformErrorKind>

Error that may be returned. Returns Infallible if it never errors

Required Methods

source

fn transform_entry<'life0, 'async_trait>( &'life0 self, entry: Entry ) -> Pin<Box<dyn Future<Output = Result<Vec<TransformedEntry>, Self::Err>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,

Transform the entry into one or several separate entries

Implementors