pub trait TransformField: Debug + Send + Sync {
    type Err: Into<TransformErrorKind>;

    // Required method
    fn transform_field(
        &self,
        old_val: Option<&str>
    ) -> Result<TransformResult<String>, Self::Err>;
}
Transform/change the value of a field of an Entry

Required Associated Types

source

type Err: Into<TransformErrorKind>

Error that may be returned. Returns Infallible if it never errors

Required Methods

source

fn transform_field( &self, old_val: Option<&str> ) -> Result<TransformResult<String>, Self::Err>

Transform/change the field into a new one or None specifying what happens if None is returned

Errors

Refer to implementator’s docs. Most of them never error but some do

Implementors