pub struct TransformedEntry {
    pub id: TransformResult<EntryId>,
    pub reply_to: TransformResult<EntryId>,
    pub raw_contents: TransformResult<String>,
    pub msg: TransformedMessage,
}
An Entry mirror that can be converted to Entry but whose fields can be chosen to inherit old entry’s values on None Refer to Entry for more docs on itself and each field

Fields

id: TransformResult<EntryId>reply_to: TransformResult<EntryId>raw_contents: TransformResult<String>msg: TransformedMessage

Implementations

source

impl TransformedEntry

source

pub fn into_entry(self, old_entry: &Entry) -> Entry

Transform TransformedEntry into a new Entry, using old_entry’s fields as fallback if needed