Module fetcher_core::entry

source ·
This module contains the basic building blog of fetcher - Entry that is passed throughout the program and that all modules either create, modify, or consume

Structs

  • A fetcher primitive that contains a message and an id returned from a source that can be send to a sink
  • An ID that can identify and entry to differentiate it from another one