Struct fetcher_core::entry::Entry
source · pub struct Entry {
pub id: Option<EntryId>,
pub reply_to: Option<EntryId>,
pub raw_contents: Option<String>,
pub msg: Message,
}Expand description
A fetcher primitive that contains a message and an id returned from a source that can be send to a sink
Fields
id: Option<EntryId>ID of the entry
A ReadFilter can use it to differentiate already read entries from the unread ones.
It is also used to map between entries and messages to support, e.g. replies
reply_to: Option<EntryId>An entry this entry is replying to/quoting
raw_contents: Option<String>Raw contents gotten from a Source
It’s used to compose a message using transformators.
msg: MessageThe message itself