Struct fetcher_core::job::Job
source · pub struct Job {
pub tasks: Vec<Task>,
pub refresh_time: Option<TimePoint>,
}Expand description
A single job, containing a single or a couple tasks, possibly refetching every set amount of time
Fields
tasks: Vec<Task>The tasks to run
refresh_time: Option<TimePoint>Refresh/refetch/redo the job every “this” point of the day
Implementations