pub struct Message {
    pub title: Option<String>,
    pub body: Option<String>,
    pub link: Option<Url>,
    pub media: Option<Vec<Media>>,
}
The finalized and composed message meant to be sent to a sink

Fields

title: Option<String>

title of the message

body: Option<String>

body of the message

link: Option<Url>

a url to the full contents or source of the message

media: Option<Vec<Media>>

a list of photos or videos included in the message. They are usually attached to the message itself if the sink supports it. Otherwise they may be left as links

Implementations

source

impl Message

source

pub fn is_empty(&self) -> bool

Check if the message is entirely empty. Even a single media attachment will mark this message as not empty