Module fetcher_core::source

source ·
This module contains Sources that can fetch data and create new Entries out of it

Re-exports

  • pub use self::email::Email;
  • pub use self::file::File;
  • pub use self::http::Http;
  • pub use self::reddit::Reddit;
  • pub use self::twitter::Twitter;

Modules

  • A email source that uses IMAP to connect to an email server
  • This module contains all errors that can happen in the (parent)super module
  • Local file source
  • HTTP source
  • This module contains the Reddit subbreddit API source
  • Twitter feed

Structs

  • Exec source. It can execute a shell command and source its stdout
  • A wrapper around a Fetch that uses an external way to filter read entries, as well as a (read filter)ReadFilter

Traits

  • A trait that defines a way to fetch (entries)Entry
  • A trait that defines a way to fetch entries as well as mark them as read afterwards