Enum fetcher_core::source::email::ViewMode
source · pub enum ViewMode {
ReadOnly,
MarkAsRead,
Delete,
}Expand description
A view mode for the IMAP connection
Variants
ReadOnly
Completely read only, never modifies anything
MarkAsRead
Mark the read ones as read but retain them in the inbox
Delete
Delete the read ones In Gmail this normally marks them as archived, unless changed in the settings