pub enum Source {
    WithSharedReadFilter(Source),
    WithCustomReadFilter(Source),
}

Variants

WithSharedReadFilter(Source)

WithCustomReadFilter(Source)

Implementations

Get all available entries from the source and run them through the parsers

Errors
  • if there was an error fetching from the source
  • if there was an error parsing the just fetched entries