pub trait Source: Fetch + MarkAsRead + Debug + Send + Sync { }
A trait that defines a way to fetch entries as well as mark them as read afterwards

Implementors

source

impl Source for Email

source

impl<F, RF> Source for SourceWithSharedRF<F, RF>where F: Fetch, RF: ReadFilter,