Enum fetcher_core::source::with_custom_rf::Source
source · [−]pub enum Source {
Email(Email),
}Variants
Email(Email)
Implementations
sourceimpl Source
impl Source
sourcepub async fn get(&mut self) -> Result<Vec<Entry>, SourceError>
pub async fn get(&mut self) -> Result<Vec<Entry>, SourceError>
Fetch all entries from the source
Errors
if there was an error fetching from the source (such as a network connection error or maybe even an authentication error)
sourcepub async fn mark_as_read(&mut self, id: &str) -> Result<(), SourceError>
pub async fn mark_as_read(&mut self, id: &str) -> Result<(), SourceError>
Delegate for Source::mark_as_read
sourcepub fn remove_read(&self, _entries: &mut Vec<Entry>)
pub fn remove_read(&self, _entries: &mut Vec<Entry>)
Delegate for Source::remove_read