Module fetcher_core::task

source ·
This module contains the basic block of fetcher that is a Task

Modules

Structs

  • A core primitive of fetcher. Contains everything from a Source that allows to fetch some data, to a Sink that takes that data and sends it somewhere. It also contains any transformators