Struct fetcher_core::task::Task

source ·
pub struct Task {
    pub tag: Option<String>,
    pub source: Option<Box<dyn Source>>,
    pub actions: Option<Vec<Action>>,
    pub sink: Option<Box<dyn Sink>>,
    pub entry_to_msg_map: Option<EntryToMsgMap>,
}
A core primitive of fetcher. Contains everything from a Source that allows to fetch some data, to a Sink that takes that data and sends it somewhere. It also contains any transformators

Fields

tag: Option<String>

An optional tag that may be put near a message body to differentiate this task from others that may be similar

source: Option<Box<dyn Source>>

The source where to fetch some data from

actions: Option<Vec<Action>>

A list of optional transformators which to run the data received from the source through

sink: Option<Box<dyn Sink>>

The sink where to send the data to

entry_to_msg_map: Option<EntryToMsgMap>

Map of an entry to a message. Used when an entry is a reply to an older entry to be able to show that as a message, too

Implementations

source

impl Task

source

pub async fn run(&mut self) -> Result<(), Error>

Run a task (both the source and the sink part) once to completion

Errors

If there was an error fetching the data, sending the data, or saving what data was successfully sent to an external location