pub use self::html::Html;
pub use self::json::Json;
pub use self::rss::Rss;
Type that allows transformation of a single Entry into one or multiple separate entries. That includes everything from parsing a markdown format like JSON to simple transformations like making all text uppercase
Entry