pub enum Transform {
    Http,
    Html(Html),
    Json(Json),
    Rss(Rss),
    ReadFilter(Arc<RwLock<ReadFilter>>),
    UseRawContents,
    Caps,
    Print,
}
Type that allows transformation of a single Entry into one or multiple separate entries. That includes everything from parsing a markdown format like JSON to simple transformations like making all text uppercase

Variants

Http

Html(Html)

Json(Json)

Rss(Rss)

ReadFilter(Arc<RwLock<ReadFilter>>)

UseRawContents

use raw_contents as message’s body

Caps

Print

Implementations

Transform the entry entry into one or more entries

Errors

if there was an error parsing the entry