Crate fetcher_core
source · [−]Expand description
fetcher core // TODO
Modules
Everything concerning some kind of non-primitive authentication
Contains Entry - a struct that contains a message that can be fed into a [Sink] and an id that can be used with a ReadFilter
Every error this crate and any of its modules may return, plus some helper functions
Filtering already read entries and marking what entries have already been read
Sending fetched data
Fetching data
Functions
Run a task (both the source and the sink part) once to completion