pub trait Transform: Debug + Send + Sync {
// Required method
fn transform<'life0, 'async_trait>(
&'life0 self,
entry: Entry
) -> Pin<Box<dyn Future<Output = Result<Vec<Entry>, TransformError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}
Transform an Entry into one or more new (entries)Entry.
For example, a Json transform parses the contents of the Entry as JSON and returns new entries from it,
while the Caps field transform just makes a field uppercase
Transform an Entry to one or more entries
Refer to implementators docs