Module fetcher_core::entry
source · Expand description
Structs
- A
fetcherprimitive that contains a message and an id returned from a source that can be send to a sink - An ID that can identify and entry to differentiate it from another one
fetcher primitive that contains a message and an id returned from a source that can be send to a sink