Contains Entry - a struct that contains a message that can be fed into a [Sink] and an id that can be used with a ReadFilter

Structs

A fetcher primitive that contains a message and an id returned from a source that can be send to a sink