Module fetcher_core::entry
source · [−]Expand description
Contains Entry - a struct that contains a message that can be fed into a [Sink] and an id that can be used with a ReadFilter
Contains Entry - a struct that contains a message that can be fed into a [Sink] and an id that can be used with a ReadFilter