Struct fetcher_core::entry::Entry
source · [−]Expand description
A fetcher primitive that contains a message and an id returned from a source that can be send to a sink
Fields
id: Option<String>An optional id of that entry. A ReadFilter can use it to differentiate already read entries from the unread ones
raw_contents: Option<String>Raw contents gotten from a [Source].
It’s used to compose a message using transformators.
msg: MessageThe message itself